@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.104 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: chr.h,v 1.105 2007/02/03 00:10:00 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -45,6 +45,8 @@
 #include	"mnstr-kind.h"
 #include	"item-kind.h"
 
+#include	"gfile.h"
+
 /***************************************************************
 * иͤȥ٥
 ***************************************************************/
@@ -798,6 +800,9 @@ typedef struct chr_t {
 
 	/* ¾ */
 	chr_work_t	work;
+
+	/* xlnl ե̾ */
+	char	graph_name[FILE_NAME_MAX_LEN + 1];
 } chr_t;
 
 #endif	/* CHR_H */
