@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.68 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: curs.c,v 1.71 2007/02/04 23:09:23 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -130,6 +130,7 @@ void	init_curs( void )
 {
 	flg_curs = 0;
 	flg_curs_draw = 0;
+	curs_attrset_dflt();
 }
 
 /***************************************************************
@@ -139,32 +140,45 @@ void	init_curs( void )
 
 bool_t	init_curs_color( void )
 {
-#if	HAVE_LIBCURSES
 	long	n;
 
-	if( !g_flg_cui )
-		return FALSE;
-
 	flg_color = TRUE;
 
+	if( g_flg_gui && !g_flg_cui ){
+		flg_color = TRUE;
+		for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
+			short	pair_n;
+
+			pair_n = n + 1;
+			init_curs_color_pair( &(g_curs_attr[n]), pair_n );
+			g_curs_attr[n].color_pair_n = pair_n;
+		}
+		return TRUE;
+	}
+
+#if	HAVE_LIBCURSES
 # if	HAVE_HAS_COLORS
-	if( !has_colors() ){
+	if( g_flg_cui && !has_colors() ){
 		flg_color = FALSE;
 		return FALSE;
 	}
 # else	/* HAVE_HAS_COLORS */
+	flg_color = FALSE;
 	return FALSE;
 # endif	/* HAVE_HAS_COLORS */
 
 # if	HAVE_START_COLOR
-	if( start_color() != OK ){
+	if( g_flg_cui && (start_color() != OK) ){
 		flg_color = FALSE;
 		return FALSE;
 	}
 # else	/* HAVE_START_COLOR */
+	flg_color = FALSE;
 	return FALSE;
 # endif	/* HAVE_START_COLOR */
+#endif	/* HAVE_LIBCURSES */
 
+	flg_color = TRUE;
 	for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
 		short	pair_n;
 
@@ -172,7 +186,6 @@ bool_t	init_curs_color( void )
 		init_curs_color_pair( &(g_curs_attr[n]), pair_n );
 		g_curs_attr[n].color_pair_n = pair_n;
 	}
-#endif	/* HAVE_LIBCURSES */
 	return TRUE;
 }
 
@@ -186,18 +199,17 @@ bool_t	init_curs_color( void )
 bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 {
 #if	HAVE_LIBCURSES
-	if( !g_flg_cui )
-		return FALSE;
-
 	if( !flg_color )
 		return FALSE;
 
 # if	HAVE_INIT_PAIR
-	init_pair( pair_n, p->fg, p->bg );
+	if( g_flg_cui )
+		init_pair( pair_n, p->fg, p->bg );
 # endif	/* HAVE_INIT_PAIR */
-	p->color_pair_n = pair_n;
 #endif	/* HAVE_LIBCURSES */
 
+	p->color_pair_n = pair_n;
+
 	return TRUE;
 }
 
@@ -208,10 +220,13 @@ bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 
 bool_t	chk_curs_draw( void )
 {
-	if( !g_flg_cui )
+	if( flg_curs_draw <= 0 )
 		return FALSE;
 
-	if( flg_curs_draw <= 0 )
+	if( g_flg_gui )
+		return TRUE;
+
+	if( !g_flg_cui )
 		return FALSE;
 
 	return TRUE;
@@ -245,10 +260,13 @@ bool_t	chk_curs( void )
 	if( !g_flg_use_curs )
 		return FALSE;
 
-	if( !g_flg_cui )
+	if( flg_curs <= 0 )
 		return FALSE;
 
-	if( flg_curs <= 0 )
+	if( g_flg_gui )
+		return TRUE;
+
+	if( !g_flg_cui )
 		return FALSE;
 
 	return TRUE;
@@ -260,10 +278,7 @@ bool_t	chk_curs( void )
 
 void	ena_curs( void )
 {
-	if( !g_flg_cui )
-		return;
-
-	if( chk_curs() ){
+	if( g_flg_cui && chk_curs() ){
 		curs_noecho();
 		curs_cbreak();
 		curs_raw();
@@ -276,10 +291,7 @@ void	ena_curs( void )
 
 void	dis_curs( void )
 {
-	if( !g_flg_cui )
-		return;
-
-	if( chk_curs() ){
+	if( g_flg_cui && chk_curs() ){
 		curs_noraw();
 		curs_nocbreak();
 		curs_echo();
@@ -294,15 +306,14 @@ void	dis_curs( void )
 
 void	curs_clearok( WINDOW *win, bool_t bf )
 {
-	if( !g_flg_cui )
-		return;
-
 	flg_curs++;
 
 #if	HAVE_LIBCURSES
 	if( flg_curs == 1 ){
 		if( chk_curs() ){
-			clearok( win, bf );
+			if( g_flg_cui ){
+				clearok( win, bf );
+			}
 			ena_curs();
 		}
 	}
@@ -315,15 +326,14 @@ void	curs_clearok( WINDOW *win, bool_t bf )
 
 void	curs_initscr( void )
 {
-	if( !g_flg_cui )
-		return;
-
 	flg_curs++;
 
 #if	HAVE_LIBCURSES
 	if( flg_curs == 1 ){
 		if( chk_curs() ){
-			initscr();
+			if( g_flg_cui ){
+				initscr();
+			}
 			ena_curs();
 			init_curs_color();
 		}
@@ -337,15 +347,14 @@ void	curs_initscr( void )
 
 void	curs_endwin( void )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( flg_curs == 1 ){
 
 #if	HAVE_LIBCURSES
 		if( chk_curs() ){
 			dis_curs();
-			endwin();
+			if( g_flg_cui ){
+				endwin();
+			}
 		}
 #endif	/* HAVE_LIBCURSES */
 
@@ -366,14 +375,13 @@ void	curs_endwin( void )
 
 void	curs_keypad( WINDOW *win, bool_t bf )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( g_flg_use_keypad ){
 		if( chk_curs() ){
 # if	HAVE_KEYPAD
-			keypad( win, bf );
+			if( g_flg_cui ){
+				keypad( win, bf );
+			}
 # endif	/* HAVE_KEYPAD */
 		}
 	}
@@ -386,22 +394,20 @@ void	curs_keypad( WINDOW *win, bool_t bf )
 
 void	curs_refresh( void )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( !chk_curs_draw() )
 		return;
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		if( chk_curs() ){
+		if( g_flg_cui ){
 			refresh();
 			return;
 		}
 	}
 #endif	/* HAVE_LIBCURSES */
 
-	fflush( OUT_FP );
+	if( g_flg_cui )
+		fflush( OUT_FP );
 }
 
 /***************************************************************
@@ -420,9 +426,6 @@ curs_attr_t	get_current_attr( void )
 
 void	curs_attrset_dflt( void )
 {
-	if( !g_flg_cui )
-		return;
-
 	curs_attrset_dir( &(g_curs_attr[CURS_ATTR_N_NORMAL]) );
 }
 
@@ -433,9 +436,6 @@ void	curs_attrset_dflt( void )
 
 void	curs_attrset_n( curs_attr_n_t n )
 {
-	if( !g_flg_cui )
-		return;
-
 	curs_attrset_dir( &(g_curs_attr[n]) );
 }
 
@@ -448,9 +448,6 @@ void	curs_attrset_dir( curs_attr_t *attr )
 {
 	long	tmp_attr;
 
-	if( !g_flg_cui )
-		return;
-
 	g_current_attr = *attr;
 
 	if( !chk_curs_draw() )
@@ -474,23 +471,22 @@ void	curs_attrset_dir( curs_attr_t *attr )
 
 void	curs_attrset( long at )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( !chk_curs_draw() )
 		return;
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
 # if	HAVE_ATTRSET
-		attrset( at );
+		if( g_flg_cui ){
+			attrset( at );
+		}
 # endif	/* HAVE_ATTRSET */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
 
 #if	D_DOS
-	{
+	if( g_flg_cui ){
 		HANDLE hStdOut;
 		WORD wAttributes;
 
@@ -502,10 +498,12 @@ void	curs_attrset( long at )
 #endif	/* D_DOS */
 
 #if	FLG_PRINT_REVERSE
-	if( chk_flg( at, A_REVERSE ) )
-		fprintf( OUT_FP, "\033[43m" );
-	else
-		fprintf( OUT_FP, "\033[m" );
+	if( g_flg_cui ){
+		if( chk_flg( at, A_REVERSE ) )
+			fprintf( OUT_FP, "\033[43m" );
+		else
+			fprintf( OUT_FP, "\033[m" );
+	}
 #endif	/* FLG_PRINT_REVERSE */
 }
 
@@ -516,23 +514,25 @@ void	curs_attrset( long at )
 
 void	curs_attron( long at )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( !chk_curs_draw() )
 		return;
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
 # if	HAVE_ATTRON
-		attron( at );
+		if( g_flg_cui ){
+			attron( at );
+		}
 # endif	/* HAVE_ATTRON */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
+
 #if	FLG_PRINT_REVERSE
-	if( chk_flg( at, A_REVERSE ) )
-		fprintf( OUT_FP, "\033[43m" );
+	if( g_flg_cui ){
+		if( chk_flg( at, A_REVERSE ) )
+			fprintf( OUT_FP, "\033[43m" );
+	}
 #endif	/* FLG_PRINT_REVERSE */
 }
 
@@ -543,23 +543,25 @@ void	curs_attron( long at )
 
 void	curs_attroff( long at )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( !chk_curs_draw() )
 		return;
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
 # if	HAVE_ATTROFF
-		attroff( at );
+		if( g_flg_cui ){
+			attroff( at );
+		}
 # endif	/* HAVE_ATTROFF */
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
+
 #if	FLG_PRINT_REVERSE
-	if( chk_flg( at, A_REVERSE ) )
-		fprintf( OUT_FP, "\033[m" );
+	if( g_flg_cui ){
+		if( chk_flg( at, A_REVERSE ) )
+			fprintf( OUT_FP, "\033[m" );
+	}
 #endif	/* FLG_PRINT_REVERSE */
 }
 
@@ -579,12 +581,11 @@ curs_attr_t	*get_curs_attr( void )
 
 void	curs_echo( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		echo();
+		if( g_flg_cui ){
+			echo();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -595,12 +596,11 @@ void	curs_echo( void )
 
 void	curs_noecho( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		noecho();
+		if( g_flg_cui ){
+			noecho();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -611,12 +611,11 @@ void	curs_noecho( void )
 
 void	curs_cbreak( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		cbreak();
+		if( g_flg_cui ){
+			cbreak();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -627,12 +626,11 @@ void	curs_cbreak( void )
 
 void	curs_nocbreak( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		nocbreak();
+		if( g_flg_cui ){
+			nocbreak();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -643,12 +641,11 @@ void	curs_nocbreak( void )
 
 void	curs_raw( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		raw();
+		if( g_flg_cui ){
+			raw();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -659,12 +656,11 @@ void	curs_raw( void )
 
 void	curs_noraw( void )
 {
-	if( !g_flg_cui )
-		return;
-
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		noraw();
+		if( g_flg_cui ){
+			noraw();
+		}
 	}
 #endif	/* HAVE_LIBCURSES */
 }
@@ -677,9 +673,6 @@ void	curs_noraw( void )
 
 void	curs_move( int scrn_y, int scrn_x )
 {
-	if( !g_flg_cui )
-		return;
-
 #ifndef	D_DOS
 	if( !chk_curs_draw() )
 		return;
@@ -687,13 +680,15 @@ void	curs_move( int scrn_y, int scrn_x )
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		move( scrn_y, scrn_x );
+		if( g_flg_cui ){
+			move( scrn_y, scrn_x );
+		}
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
 
 #ifdef	D_DOS
-	{
+	if( g_flg_cui ){
 		COORD	scrn_pos;
 
 		scrn_pos.X = scrn_x;
@@ -705,7 +700,8 @@ void	curs_move( int scrn_y, int scrn_x )
 	}
 #endif	/* D_DOS */
 
-	fprintf( OUT_FP, "\033[%d;%dH", scrn_y + 1, scrn_x + 1 );
+	if( g_flg_cui )
+		fprintf( OUT_FP, "\033[%d;%dH", scrn_y + 1, scrn_x + 1 );
 }
 
 /***************************************************************
@@ -745,25 +741,26 @@ void	curs_printw( char *s, ... )
 
 void	curs_clear( void )
 {
-	if( !g_flg_cui )
-		return;
-
 	if( !chk_curs_draw() )
 		return;
 
 #if	HAVE_LIBCURSES
 	if( chk_curs() ){
-		clear();
+		if( g_flg_cui ){
+			clear();
+		}
 		return;
 	}
 #endif	/* HAVE_LIBCURSES */
 
 #ifdef	D_X68K
-	fprintf( OUT_FP, "\032" );
+	if( g_flg_cui ){
+		fprintf( OUT_FP, "\032" );
+	}
 	return;
 #endif	/* D_X68K */
 
-	{
+	if( g_flg_cui ){
 		long	i;
 		const long	max_n = get_max_line();
 
@@ -902,16 +899,13 @@ int	attr_dos( curs_attr_t *attr )
 	int	a;
 	short	fg, bg;
 
-	if( !g_flg_cui )
+	if( attr == NULL )
 		return 0;
 
 	a = 0;
 	fg = 0;
 	bg = 0;
 
-	if( attr == NULL )
-		return 0;
-
 #ifdef	D_DOS
 	if( chk_flg( attr->attr, A_BOLD ) )
 		a |= FOREGROUND_INTENSITY;
