@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.97 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: dun.c,v 1.99 2007/02/18 22:49:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -3100,24 +3100,10 @@ door_t	*get_door_nearest( long x, long y, act_kind_t act_kind )
 
 		if( !chk_mark_door( p, act_kind ) )
 			continue;
-
 		if( !chk_find_door( dr_n ) )
 			continue;
 
-		if( p->x >= x ){
-			dx = labs( p->x - x );
-			pos1.x = p->x;
-		} else {
-			dx = labs( x - (p->x + p->dx - 1) );
-			pos1.x = p->x + p->dx - 1;
-		}
-		if( p->y >= y ){
-			dy = labs( p->y - y );
-			pos1.y = p->y;
-		} else {
-			dy = labs( y - (p->y + p->dy - 1) );
-			pos1.y = p->y + p->dy - 1;
-		}
+		set_door_pos_chk_find( p, x, y, &pos1, &dx, &dy );
 		tmp_r = dx + dy;
 		if( tmp_r > min_r )
 			continue;
@@ -3168,24 +3154,10 @@ door_t	*get_door_near( long x, long y, act_kind_t act_kind )
 
 		if( !chk_mark_door( p, act_kind ) )
 			continue;
-
 		if( !chk_find_door( dr_n ) )
 			continue;
 
-		if( p->x >= x ){
-			dx = labs( p->x - x );
-			pos1.x = p->x;
-		} else {
-			dx = labs( x - (p->x + p->dx - 1) );
-			pos1.x = p->x + p->dx - 1;
-		}
-		if( p->y >= y ){
-			dy = labs( p->y - y );
-			pos1.y = p->y;
-		} else {
-			dy = labs( y - (p->y + p->dy - 1) );
-			pos1.y = p->y + p->dy - 1;
-		}
+		set_door_pos_chk_find( p, x, y, &pos1, &dx, &dy );
 		tmp_r = dx + dy;
 
 		pos2.x = x;
@@ -3237,24 +3209,10 @@ door_t	*get_door_disperse( mbr_t *mbr, act_kind_t act_kind )
 
 		if( !chk_mark_door( p, act_kind ) )
 			continue;
-
 		if( !chk_find_door( dr_n ) )
 			continue;
 
-		if( p->x >= x ){
-			dx = labs( p->x - x );
-			pos1.x = p->x;
-		} else {
-			dx = labs( x - (p->x + p->dx - 1) );
-			pos1.x = p->x + p->dx - 1;
-		}
-		if( p->y >= y ){
-			dy = labs( p->y - y );
-			pos1.y = p->y;
-		} else {
-			dy = labs( y - (p->y + p->dy - 1) );
-			pos1.y = p->y + p->dy - 1;
-		}
+		set_door_pos_chk_find( p, x, y, &pos1, &dx, &dy );
 		tmp_r = dx + dy;
 		if( tmp_r > min_r )
 			continue;
@@ -3305,24 +3263,10 @@ door_t	*get_door_randm( long x, long y, act_kind_t act_kind )
 
 		if( !chk_mark_door( p, act_kind ) )
 			continue;
-
 		if( !chk_find_door( dr_n ) )
 			continue;
 
-		if( p->x >= x ){
-			dx = labs( p->x - x );
-			pos1.x = p->x;
-		} else {
-			dx = labs( x - (p->x + p->dx - 1) );
-			pos1.x = p->x + p->dx - 1;
-		}
-		if( p->y >= y ){
-			dy = labs( p->y - y );
-			pos1.y = p->y;
-		} else {
-			dy = labs( y - (p->y + p->dy - 1) );
-			pos1.y = p->y + p->dy - 1;
-		}
+		set_door_pos_chk_find( p, x, y, &pos1, &dx, &dy );
 
 		pos2.x = x;
 		pos2.y = y;
@@ -3383,6 +3327,52 @@ door_t	*get_door_towner( long x, long y, long r )
 	return ret;
 }
 
+/***************************************************************
+* ΥɥȺɸå˻ȤɸȵΥ֤
+* door_t *p : ɥ
+* long x :  x ɸ
+* long y :  y ɸ
+* pos_t *pos : å˻Ȥɸ֤
+* long *dx : x εΥ֤
+* long *dy : y εΥ֤
+***************************************************************/
+
+void	set_door_pos_chk_find(
+	door_t *p, long x, long y, pos_t *pos, long *dx, long *dy
+)
+{
+	if( p == NULL )
+		return;
+	if( pos == NULL )
+		return;
+	if( dx == NULL )
+		return;
+	if( dy == NULL )
+		return;
+
+	if( p->x > x ){
+		*dx = labs( p->x - x );
+		pos->x = p->x - 1;
+	} else if( (p->x + p->dx - 1) < x ){
+		*dx = labs( x - (p->x + p->dx - 1) );
+		pos->x = p->x + p->dx - 1 + 1;
+	} else {
+		*dx = labs( p->x - x );
+		pos->x = x;
+	}
+
+	if( p->y > y ){
+		*dy = labs( p->y - y );
+		pos->y = p->y - 1;
+	} else if( (p->y + p->dy - 1) < y ){
+		*dy = labs( y - (p->y + p->dy - 1) );
+		pos->y = p->y + p->dy - 1 + 1;
+	} else {
+		*dy = labs( p->y - y );
+		pos->y = y;
+	}
+}
+
 /***************************************************************
 * ΥɥФơ󤬼¹ԲǽĴ٤
 * door_t *p : ɥ
@@ -3615,13 +3605,19 @@ bool_t	clip_draw_x( long n )
 	if( n == MAP_DEL_X )
 		return FALSE;
 
-	draw = get_map_draw_pos();
-	if( n < draw->x )
-		return FALSE;
-	if( n > (draw->x + WIN_MAP_WIDTH - 1) )
-		return FALSE;
+	if( g_flg_cui ){
+		draw = get_map_draw_pos();
+		if( (draw->x <= n)
+				&& (n <= (draw->x + WIN_MAP_WIDTH - 1)) ){
+			return TRUE;
+		}
+	}
+	if( g_flg_gui ){
+		if( call_pcg_dun_clip_win_x( n ) )
+			return TRUE;
+	}
 
-	return TRUE;
+	return FALSE;
 }
 
 /***************************************************************
@@ -3637,13 +3633,19 @@ bool_t	clip_draw_y( long n )
 	if( n == MAP_DEL_Y )
 		return FALSE;
 
-	draw = get_map_draw_pos();
-	if( n < draw->y )
-		return FALSE;
-	if( n > (draw->y + WIN_MAP_HEIGHT - 1) )
-		return FALSE;
+	if( g_flg_cui ){
+		draw = get_map_draw_pos();
+		if( (draw->y <= n)
+				&& (n <= (draw->y + WIN_MAP_WIDTH - 1)) ){
+			return TRUE;
+		}
+	}
+	if( g_flg_gui ){
+		if( call_pcg_dun_clip_win_y( n ) )
+			return TRUE;
+	}
 
-	return TRUE;
+	return FALSE;
 }
 
 /***************************************************************
