@@ -1,4 +1,4 @@
-/* main_dos.c */
+/* main-dos.c */
 
 #ifdef __cplusplus
 extern "C" {
@@ -7,6 +7,7 @@ extern "C" {
 int	main_dos( void );
 void	chk_arg( int argc, char **argv );
 bool_t	chk_opt_flg( const char *optarg );
+void	overwrite_arg();
 void	usage( FILE *fp );
 void	child_ps_dos( void );
 void	init_term_dos( void );
